The GridPolator API
===================

.. automodapi:: GridPolator
    :no-inheritance-diagram:

.. autodata:: GridPolator.config.flux_unit

.. autodata:: GridPolator.config.wl_unit

.. autodata:: GridPolator.config.teff_unit